==> okteta-0.25.1.tar.xz: okteta-0.25.1/libs/kasten/core/tests/testdocumentfileloadjob.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TESTDOCUMENTFILELOADJOB_H
#define TESTDOCUMENTFILELOADJOB_H

// Kasten core
#include <abstractfilesystemloadjob.h>

namespace Kasten {

class TestDocumentFileSynchronizer;
class TestDocumentFileLoadThread;

class TestDocumentFileLoadJob : public AbstractFileSystemLoadJob
{
    Q_OBJECT

public:
    TestDocumentFileLoadJob(TestDocumentFileSynchronizer* synchronizer, const QUrl& url);
    ~TestDocumentFileLoadJob() override;

protected: // AbstractFileSystemLoadJob API
    void startLoadFromFile() override;

protected Q_SLOTS:
//     void onDataPulled();
};

}

#endif

==> okteta_4.13.3.orig.tar.xz: okteta-4.13.3/libs/kasten/core/tests/testdocumentfileloadjob.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TESTDOCUMENTFILELOADJOB_H
#define TESTDOCUMENTFILELOADJOB_H

// Kasten core
#include <abstractfilesystemloadjob.h>


namespace Kasten2
{

class TestDocumentFileSynchronizer;
class TestDocumentFileLoadThread;

class TestDocumentFileLoadJob : public AbstractFileSystemLoadJob
{
  Q_OBJECT

  public:
    TestDocumentFileLoadJob( TestDocumentFileSynchronizer* synchronizer, const KUrl& url );
    virtual ~TestDocumentFileLoadJob();

  protected: // AbstractFileSystemLoadJob API
    virtual void startLoadFromFile();

  protected Q_SLOTS:
//     void onDataPulled();

  protected:
    TestDocumentFileLoadThread* mLoadThread;
};

}

#endif
